# Roseau Load Flow #

![CI](https://github.com/RoseauTechnologies/Roseau_Load_Flow/workflows/CI/badge.svg)
[![Documentation](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/doc.yml/badge.svg)](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/doc.yml)
[![pre-commit](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/pre-commit.yml)

*Roseau Load Flow* is a highly capable three-phase load flow solver. This project is compatible
with Python 3.9 and above.

Please take a look at our documentation to see how to install and use `roseau_load_flow`.

* [Installation](https://roseautechnologies.github.io/Roseau_Load_Flow/installation.html)
* [Usage](https://roseautechnologies.github.io/Roseau_Load_Flow/notebooks/Getting_Started.html)

# Accessing the solver #

This is the client library for the *Roseau Load Flow* solver. To use the solver, you need to sign
up for an account. For inquiry, please contact us at contact@roseautechnologies.com.

# Bug reports / Feature requests #

If you find a bug or have a feature request, please open an issue on the
[GitHub](https://github.com/RoseauTechnologies/Roseau_Load_Flow/issues)
